@@ -6,7 +6,7 @@ use strict;
 
 use base 'Number::Phone::NANP';
 
-use Number::Phone::Country qw(noexport);
+use Number::Phone::Country;
 
 our $VERSION = 1.1;
 
@@ -60,7 +60,7 @@ perl itself.
 
 David Cantrell E<lt>david@cantrell.org.ukE<gt>
 
-Copyright 2005
+Copyright 2024
 
 =cut
 
